==> ejc-tax-api-3.0.0-20210402.094252-104-sources.jar: com/ejianc/business/tax/hystrix/InvoiceHystrix.java <==
package com.ejianc.business.tax.hystrix;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.tax.api.IInvoiceApi;
import com.ejianc.business.tax.vo.*;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * 模块hystrix
 *
 * @author guoming
 *
 */
@Component
public class InvoiceHystrix implements IInvoiceApi {

	@Override
	public CommonResponse<BigDecimal> getInvoiceOpenMny(Long contractId, Long orgId) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<BigDecimal> getNoContractOpenMny(Long projectId, Long customerId) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<BigDecimal> getInvoiceReceiceMny(Long contractId, Long orgId) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<IPage<InvoiceOpenVO>> invoiceOpenRef(Integer pageNumber, Integer pageSize, String condition, String searchText) {
		return CommonResponse.error("网络问题， 查询失败。");
	}
	@Override
	public CommonResponse<JSONObject> invoiceReceiveRef(QueryParam queryParam) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<InvoiceReceiveRecordVO> getInvoiceReceiveRecord(Long id) {
		return CommonResponse.error("网络问题， 查询失败。");
	}
	@Override
	public CommonResponse<InvoiceOpenRecordVO> getInvoiceOpenRecord(Long id) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updateFlag(List<InvoiceReceiveFlagVO> invoiceReceiveFlagVOS) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<BigDecimal> countInvoiceOpenByProperties(Map<String, Object> param) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<Map<String, InvoiceMnyWarnVO>> getInvoiceMnyByTenantIds(InvoicePubWarnQueryVO pubWarnQueryVO) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<JSONObject> getReceiveListByQueryParam(QueryParam queryParam) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<JSONObject> getOpenListByQueryParam(QueryParam queryParam) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<BigDecimal> sumContractMny(Long projectId) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<InvoiceReceiveVO>> getTaxReceive(Long projectId) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

}

==> ejc-tax-api-3.0.0-20210419.111614-106-sources.jar: com/ejianc/business/tax/hystrix/InvoiceHystrix.java <==
package com.ejianc.business.tax.hystrix;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.tax.api.IInvoiceApi;
import com.ejianc.business.tax.vo.*;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * 模块hystrix
 *
 * @author guoming
 *
 */
@Component
public class InvoiceHystrix implements IInvoiceApi {

	@Override
	public CommonResponse<BigDecimal> getInvoiceOpenMny(Long contractId, Long orgId) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<BigDecimal> getNoContractOpenMny(Long projectId, Long customerId) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<BigDecimal> getInvoiceReceiceMny(Long contractId, Long orgId) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<IPage<InvoiceOpenVO>> invoiceOpenRef(Integer pageNumber, Integer pageSize, String condition, String searchText) {
		return CommonResponse.error("网络问题， 查询失败。");
	}
	@Override
	public CommonResponse<JSONObject> invoiceReceiveRef(QueryParam queryParam) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<InvoiceReceiveRecordVO> getInvoiceReceiveRecord(Long id) {
		return CommonResponse.error("网络问题， 查询失败。");
	}
	@Override
	public CommonResponse<InvoiceOpenRecordVO> getInvoiceOpenRecord(Long id) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> updateFlag(List<InvoiceReceiveFlagVO> invoiceReceiveFlagVOS) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<BigDecimal> countInvoiceOpenByProperties(Map<String, Object> param) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<Map<String, InvoiceMnyWarnVO>> getInvoiceMnyByTenantIds(InvoicePubWarnQueryVO pubWarnQueryVO) {
		return CommonResponse.error("网络问题， 查询失败。");
	}
	@Override
	public CommonResponse<Map<String, InvoiceMnyWarnVO>> getWarnInvoiceMny(InvoicePubWarnQueryVO pubWarnQueryVO) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<JSONObject> getReceiveListByQueryParam(QueryParam queryParam) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<JSONObject> getOpenListByQueryParam(QueryParam queryParam) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<BigDecimal> sumContractMny(Long projectId) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<InvoiceReceiveVO>> getTaxReceive(Long projectId) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

}
